Module callback

Module callback 

Helpers to work with extern “C” callbacks.

Traits

Callback
This trait allows us to treat callbacks with different number and type of arguments uniformly.
CallbackArgs
Trait for arguments to callbacks. This is similar to Default, but allows us to implement it for foreign types that don’t already implement Default.