Test utilities.
Structs
- Send
Wrapper - Unsafe wrapper for passing non-Send types through mpsc channels. Use with caution!
- User
Data - User data wrapper.
Enums
- Test
Error - Dummy error type for testing that implements ErrorCode.
Functions
- call_0
- Call a FFI function and block until its callback gets called.
Use this if the callback accepts no arguments in addition to
user_dataanderror_code. - call_
0_ with_ custom - Call a FFI function and block until its callback gets called.
Use this if the callback accepts no arguments in addition to
user_dataanderror_code. This version of the function takes aUserDatawith custom inner data. - call_1⚠
- Call an FFI function and block until its callback gets called, then return
the argument which were passed to that callback.
Use this if the callback accepts one argument in addition to
user_dataanderror_code. - call_2⚠
- Call a FFI function and block until its callback gets called, then return
the argument which were passed to that callback.
Use this if the callback accepts two arguments in addition to
user_dataanderror_code. - call_
1_ with_ custom - Call an FFI function and block until its callback gets called, then return
the argument which were passed to that callback.
Use this if the callback accepts one argument in addition to
user_dataanderror_code. This version of the function takes aUserDatawith custom inner data. - call_
2_ ⚠with_ custom - Call a FFI function and block until its callback gets called, then return
the argument which were passed to that callback.
Use this if the callback accepts two arguments in addition to
user_dataanderror_code. This version of the function takes aUserDatawith custom inner data. - call_
vec ⚠ - Call a FFI function and block until its callback gets called, then copy
the array argument which was passed to
Vec<T>and return the result. Use this if the callback accepts*const Tandusize(length) arguments in addition touser_dataanderror_code. - call_
vec_ ⚠u8 - Call a FFI function and block until its callback gets called, then copy
the byte array argument which was passed to
Vec<u8>and return the result. - call_
vec_ ⚠u8_ with_ custom - Call a FFI function and block until its callback gets called, then copy
the byte array argument which was passed to
Vec<u8>and return the result. This version of the function takes aUserDatawith custom inner data. This version of the function takes aUserDatawith custom inner data. - call_
vec_ ⚠with_ custom - Call a FFI function and block until its callback gets called, then copy
the array argument which was passed to
Vec<T>and return the result. Use this if the callback accepts*const Tandusize(length) arguments in addition touser_dataanderror_code. This version of the function takes aUserDatawith custom inner data. - send_
via_ ⚠user_ data - Send through a
mpsc::Senderpointed to by the user data’s common pointer. - send_
via_ ⚠user_ data_ custom - Send through a
mpsc::Senderpointed to by the user data’s custom pointer. - sender_
as_ user_ data - Convert a
mpsc::Sender<T>to a void ptr which is then stored in theUserDatastruct and passed to ffi functions. - user_
data_ as_ void - Convert a
UserDatato a void pointer which can be passed to ffi functions.